abacusai.api_class.ai_chat — AbacusAI documentation

# abacusai.api_class.ai_chat

## Classes

`HotkeyPrompt` | A config class for a Data Science Co-Pilot Hotkey

## Module Contents

class abacusai.api_class.ai_chat.HotkeyPrompt

  Bases: `abacusai.api_class.abstract.ApiClass`

  A config class for a Data Science Co-Pilot Hotkey

  Parameters:

    - prompt (str) – The prompt to send to Data Science Co-Pilot

    - title (str) – A short, descriptive title for the prompt. If not provided, one will be automatically generated.

  prompt: str
  title: str = None
  disable_problem_type_context: bool = True
  ignore_history: bool = None